<?php

/**
 * Add custom.css if file exist.
 */
$custom_css = path_to_theme() .'/custom.css';
if (file_exists($custom_css)) {
  drupal_add_css($custom_css, 'theme');
}

/**
 * Sets the body-tag class attribute.
 *
 * @return
 *   'sidebar-left', 'sidebar-right', 'both-sidebars' or 'no-sidebars'
 *   classes as needed.
 */
function phptemplate_body_class($sidebar_left, $sidebar_right) {
  if ($sidebar_left != '' && $sidebar_right != '') {
    $class = 'two-sidebars';
  }
  else {
    if ($sidebar_left != '') {
      $class = 'sidebar-left';
    }
    if ($sidebar_right != '') {
      $class = 'sidebar-right';
    }
  }

  return $class ? $class : 'no-sidebars';
}

/**
 * Return a cascade primary links.
 * Clone implementation from user_block().
 *
 * @return
 *   a themed cascade primary links.
 */
function phptemplate_primary() {
  $output = '<div id="primary-links-region">';
  $output .= theme('menu_tree', variable_get('menu_primary_menu', 0));
  $output .= '</div>';
  return $output;
}

/**
 * Return a themed mission trail.
 *
 * @return
 *   a string containing the mission output, or execute PHP code snippet if
 *   mission is enclosed with <?php ?>.
 */
function phptemplate_mission() {
  $mission = theme_get_setting('mission');
  if (preg_match('/^<\?php/', $mission)) {
    $mission = drupal_eval($mission);
  }
  else {
    $mission = filter_xss_admin($mission);
  }
  return isset($mission) ? $mission : '';
}

/**
 * Return a themed breadcrumb trail.
 *
 * @param $breadcrumb
 *   An array containing the breadcrumb links.
 * @return a string containing the breadcrumb output.
 */
function phptemplate_breadcrumb($breadcrumb) {
  if (!empty($breadcrumb)) {
    return '<div class="breadcrumb">'. implode('', $breadcrumb) .'</div>';
  }
}
